@@ -8,7 +8,7 @@
  *
  * 1. Copyright Notice
  *
- * Some or all of this work - Copyright (c) 1999 - 2016, Intel Corp.
+ * Some or all of this work - Copyright (c) 1999 - 2020, Intel Corp.
  * All rights reserved.
  *
  * 2. License
@@ -111,11 +111,47 @@
  * other governmental approval, or letter of assurance, without first obtaining
  * such license, approval or letter.
  *
+ *****************************************************************************
+ *
+ * Alternatively, you may choose to be licensed under the terms of the
+ * following license:
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *    notice, this list of conditions, and the following disclaimer,
+ *    without modification.
+ * 2. Redistributions in binary form must reproduce at minimum a disclaimer
+ *    substantially similar to the "NO WARRANTY" disclaimer below
+ *    ("Disclaimer") and any redistribution must be conditioned upon
+ *    including a substantially similar Disclaimer requirement for further
+ *    binary redistribution.
+ * 3. Neither the names of the above-listed copyright holders nor the names
+ *    of any contributors may be used to endorse or promote products derived
+ *    from this software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
+ * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
+ * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
+ * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
+ * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
+ * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
+ * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * Alternatively, you may choose to be licensed under the terms of the
+ * GNU General Public License ("GPL") version 2 as published by the Free
+ * Software Foundation.
+ *
  *****************************************************************************/
 
 #include "acpidump.h"
 
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined (__DragonFly__)
 #include <kenv.h>
 #endif
 #include <unistd.h>
@@ -283,8 +319,8 @@ AcpiOsGetTableByName (
     /* Instance is only valid for SSDT/UEFI tables */
 
     if (Instance &&
-        !ACPI_COMPARE_NAME (Signature, ACPI_SIG_SSDT) &&
-        !ACPI_COMPARE_NAME (Signature, ACPI_SIG_UEFI))
+        !ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_SSDT) &&
+        !ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_UEFI))
     {
         return (AE_LIMIT);
     }
@@ -301,7 +337,7 @@ AcpiOsGetTableByName (
      * If one of the main ACPI tables was requested (RSDT/XSDT/FADT),
      * simply return it immediately.
      */
-    if (ACPI_COMPARE_NAME (Signature, ACPI_SIG_XSDT))
+    if (ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_XSDT))
     {
         if (!Gbl_Revision)
         {
@@ -313,7 +349,7 @@ AcpiOsGetTableByName (
         return (AE_OK);
     }
 
-    if (ACPI_COMPARE_NAME (Signature, ACPI_SIG_RSDT))
+    if (ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_RSDT))
     {
         if (!Gbl_Rsdp.RsdtPhysicalAddress)
         {
@@ -325,7 +361,7 @@ AcpiOsGetTableByName (
         return (AE_OK);
     }
 
-    if (ACPI_COMPARE_NAME (Signature, ACPI_SIG_FADT))
+    if (ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_FADT))
     {
         *Address = Gbl_FadtAddress;
         *Table = (ACPI_TABLE_HEADER *) Gbl_Fadt;
@@ -448,7 +484,7 @@ static ACPI_STATUS
 OslTableInitialize (
     void)
 {
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined(__DragonFly__)
     char                    Buffer[32];
 #endif
     ACPI_TABLE_HEADER       *MappedTable;
@@ -458,7 +494,9 @@ OslTableInitialize (
     ACPI_SIZE               RsdpSize;
     ACPI_STATUS             Status;
     u_long                  Address = 0;
+#if defined(SYSTEM_SYSCTL)
     size_t                  Length = sizeof (Address);
+#endif
 
 
     /* Get main ACPI tables from memory on first invocation of this function */
@@ -474,12 +512,13 @@ OslTableInitialize (
     {
         Address = Gbl_RsdpBase;
     }
-#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
+#if defined(__FreeBSD__) || defined(__FreeBSD_kernel__) || defined (__DragonFly__)
     else if (kenv (KENV_GET, SYSTEM_KENV, Buffer, sizeof (Buffer)) > 0)
     {
         Address = strtoul (Buffer, NULL, 0);
     }
 #endif
+#if defined(SYSTEM_SYSCTL)
     if (!Address)
     {
         if (sysctlbyname (SYSTEM_SYSCTL, &Address, &Length, NULL, 0) != 0)
@@ -487,6 +526,7 @@ OslTableInitialize (
             Address = 0;
         }
     }
+#endif
     if (Address)
     {
         RsdpBase = Address;
@@ -648,15 +688,15 @@ OslGetTableViaRoot (
 
     /* DSDT and FACS address must be extracted from the FADT */
 
-    if (ACPI_COMPARE_NAME (Signature, ACPI_SIG_DSDT) ||
-        ACPI_COMPARE_NAME (Signature, ACPI_SIG_FACS))
+    if (ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_DSDT) ||
+        ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_FACS))
     {
         /*
          * Get the appropriate address, either 32-bit or 64-bit. Be very
          * careful about the FADT length and validate table addresses.
          * Note: The 64-bit addresses have priority.
          */
-        if (ACPI_COMPARE_NAME (Signature, ACPI_SIG_DSDT))
+        if (ACPI_COMPARE_NAMESEG (Signature, ACPI_SIG_DSDT))
         {
             if ((Gbl_Fadt->Header.Length >= MIN_FADT_FOR_XDSDT) &&
                 Gbl_Fadt->XDsdt)
@@ -719,7 +759,7 @@ OslGetTableViaRoot (
 
             /* Does this table match the requested signature? */
 
-            if (ACPI_COMPARE_NAME (MappedTable->Signature, Signature))
+            if (ACPI_COMPARE_NAMESEG (MappedTable->Signature, Signature))
             {
 
                 /* Match table instance (for SSDT/UEFI tables) */
@@ -822,18 +862,18 @@ OslAddTablesToList(
 
         case 1:
 
-            ACPI_MOVE_NAME (NewInfo->Signature,
+            ACPI_COPY_NAMESEG (NewInfo->Signature,
                 Gbl_Revision ? ACPI_SIG_XSDT : ACPI_SIG_RSDT);
             break;
 
         case 2:
 
-            ACPI_MOVE_NAME (NewInfo->Signature, ACPI_SIG_FACS);
+            ACPI_COPY_NAMESEG (NewInfo->Signature, ACPI_SIG_FACS);
             break;
 
         default:
 
-            ACPI_MOVE_NAME (NewInfo->Signature, ACPI_SIG_DSDT);
+            ACPI_COPY_NAMESEG (NewInfo->Signature, ACPI_SIG_DSDT);
 
         }
 
@@ -879,7 +919,7 @@ OslAddTablesToList(
         while (NewInfo->Next != NULL)
         {
             NewInfo = NewInfo->Next;
-            if (ACPI_COMPARE_NAME (Table->Signature, NewInfo->Signature))
+            if (ACPI_COMPARE_NAMESEG (Table->Signature, NewInfo->Signature))
             {
                 Instance++;
             }
@@ -892,7 +932,7 @@ OslAddTablesToList(
             return (AE_NO_MEMORY);
         }
 
-        ACPI_MOVE_NAME (NewInfo->Signature, Table->Signature);
+        ACPI_COPY_NAMESEG (NewInfo->Signature, Table->Signature);
 
         AcpiOsUnmapMemory (Table, sizeof (*Table));
 
@@ -954,7 +994,7 @@ OslMapTable (
     /* If specified, signature must match */
 
     if (Signature &&
-        !ACPI_COMPARE_NAME (Signature, MappedTable->Signature))
+        !ACPI_COMPARE_NAMESEG (Signature, MappedTable->Signature))
     {
         AcpiOsUnmapMemory (MappedTable, sizeof (*MappedTable));
         return (AE_NOT_EXIST);
